@@ -3,7 +3,7 @@
 # 描述:
 # @author:  <a href="mailto:zuiwoxing@qq.com">dejian.liu</a>
 # @date:  2022-08-15 16:53
-from requests import Response
+from requests import
 from ldj.feign.decorator.FeignApi import FeignApi
 from ldj.example.dto.models import QueryDto
 from ldj.feign.enums.Method import Method
